/**
 * Environment object that specifies communication endpoints for the SDK
 * @export
 * @class Environment
 */
export declare class Environment {
    /**
     * Sandbox environment. This is the default one. Use it for development.
     */
    static Sandbox: Environment;
    /**
     * System Test (CSAST) environment. Use for development with System test API Key.
     */
    static SystemTest: Environment;
    /**
     * Production environment of CSAS. Use it in production with production API Key.
     */
    static Production: Environment;
    /**
    * Base URL path. Start of API context
    */
    apiContextBaseUrl: string;
    /**
     Base URL path for OAuth2 authentication.
    */
    oAuth2ContextBaseUrl: string;
    /**
     * Creates new Environment instance
     *
     * @param apiContextBaseUrl Base URL path. Start of API context
     * @param oAuth2ContextBaseUrl Base URL path for OAuth2 authentication.
     */
    constructor(apiContextBaseUrl: string, oAuth2ContextBaseUrl: string);
}
