/**
 * @export
 * @class EntityUtils
 */
export declare class EntityUtils {
    /**
     * @static
     * @param {any} obj
     * @param {any} f
     * @param {any} [ctx=null]
     * @returns
     *
     * @memberOf EntityUtils
     */
    static deepMap(obj: any, f: any, ctx?: any): any;
    /**
     * Marks response that is signable. It has SigningObject with key signing available.
     * @static
     * @param {any} object
     * @param {string} idKey
     *
     * @memberOf EntityUtils
     */
    static addIdProperty(object: any, idKey: string): void;
    /**
     * @static
     * @param {any} object
     * @returns {*}
     *
     * @memberOf EntityUtils
     */
    static copyData(object: any): any;
    /**
     * @static
     * @param {any} object
     * @param {string} oldName
     * @param {string} newName
     *
     * @memberOf EntityUtils
     */
    static renameProperty(object: any, oldName: string, newName: string): void;
    /**
     * @static
     * @param {function} accessFunction
     * @param {any} key
     * @param {function} transformFunction
     *
     * @memberOf EntityUtils
     */
    static tryTransform(accessFunction: () => any, key: any, transformFunction: (val: any) => any): void;
    /**
     * @static
     * @param {function} accessFunction
     * @param {any} key
     *
     * @memberOf EntityUtils
     */
    static tryStringToDateTransform(accessFunction: () => any, key: any): void;
    /**
     * @static
     * @param {function} accessFunction
     * @param {any} key
     *
     * @memberOf EntityUtils
     */
    static tryStringify(accessFunction: () => any, key: any): void;
    /**
     * Date.parse with progressive enhancement for ISO 8601 <https://github.com/csnover/js-iso8601>
     * NON-CONFORMANT EDITION.
     * © 2011 Colin Snover <http://zetafleet.com>
     * Released under MIT license.
     *
     * @param {any} date
     * @returns {number}
     */
    static parseISODate(date: any): number;
    /**
     * Copy all of the properties in the source objects over to the destination object,
     * and return the destination object. It's in-order, so the last source will override
     * properties of the same name in previous arguments.
     *
     * @param {object} originalParams
     * @param {object} additionalParams
     * @returns {void}
     */
    static extend(originalParams: object, additionalParams: object): void;
    /**
     * @static
     * @param {string|string[]} dates
     * @param {any} obj
     * @returns {void}
     *
     * @memberOf EntityUtils
     */
    static addDatesFromISO(dates: string | [string], obj: any): void;
    /**
     * @static
     * @param {any} dates
     * @param {any} obj
     * @param {string} [items] itemsKey
     * @returns {void}
     *
     * @memberOf EntityUtils
     */
    static addDatesToItems(dates: any, obj: any, itemsKey?: string): void;
    /**
     * @static
     * @param {any} dates
     * @param {object} obj
     * @returns {void}
     *
     * @memberOf EntityUtils
     */
    static transformDatesToISO(dates: any, obj: object): void;
    /**
     * @static
     * @param {any} dates
     * @param {object} obj
     * @returns {void}
     *
     * @memberOf EntityUtils
     */
    static transformDatesToSimpleISO(dates: any, obj: object): void;
    /**
     * @static
     * @param {any} params
     * @param {any} paramKey
     * @returns {void}
     *
     * @memberOf EntityUtils
     */
    static transformArrayParamsToString(params: any, paramKey: any): void;
    /**
     * @static
     * @param {string} path
     * @param {any} params
     * @returns {string}
     *
     * @memberOf EntityUtils
     */
    static addParamsToPath(path: string, params: any): string;
    /**
     * @private
     * @static
     * @param {any} params
     * @param {any} paramKey
     * @returns {void}
     *
     * @memberOf EntityUtils
     */
    private static transformParamsToString(params, paramKey);
    /**
     * @private
     * @static
     * @param {any} date
     * @param {any} obj
     * @returns {void}
     *
     * @memberOf EntityUtils
     */
    private static addISODate(date, obj);
}
