/**
 * Environment object that specifies communication endpoints for the SDK
 * @export
 * @class Environment
 */
export class Environment {
  /**
   * Sandbox environment. This is the default one. Use it for development.
   */
  public static Sandbox = new Environment("https://api.csas.cz/sandbox/webapi", "https://api.csas.cz/sandbox/widp/oauth2")

  /**
   * System Test (CSAST) environment. Use for development with System test API Key.
   */
  public static SystemTest = new Environment(
    "http://www.csast.csas.cz/webapi","https://bezpecnost.csast.csas.cz/mep/fs/fl/oauth2"
  )

  /**
   * Production environment of CSAS. Use it in production with production API Key.
   */
  public static Production = new Environment("https://www.csas.cz/webapi", "https://www.csas.cz/widp/oauth2")

  /**
  * Base URL path. Start of API context
  */
  apiContextBaseUrl: string;

  /**
   Base URL path for OAuth2 authentication.
  */
  oAuth2ContextBaseUrl: string;

  /**
   * Creates new Environment instance
   *
   * @param apiContextBaseUrl Base URL path. Start of API context
   * @param oAuth2ContextBaseUrl Base URL path for OAuth2 authentication.
   */
  public constructor(apiContextBaseUrl: string, oAuth2ContextBaseUrl: string) {
    this.apiContextBaseUrl = apiContextBaseUrl;
    this.oAuth2ContextBaseUrl = oAuth2ContextBaseUrl;
  }
}

