// <reference path="../../../typings/es6-promise/es6-promise.d.ts" />
// <reference path="../../../typings/jasmine/jasmine.d.ts" />
import {
    ResourceUtils,
    Resource,
    InstanceResource,
    HasInstanceResource,
    GetEnabled,
    UpdateEnabled,
    CreateEnabled,
    DeleteEnabled,
    ListEnabled,
    Paginated,
    ListResponse,
    EmptyResponse,
    Signable,
    SigningUtils } from '../../../lib/core-sdk'

export interface Post{
    id : number
    userId : number,
    title : string,
    body : string
}



export class PostsResource extends Resource implements
     HasInstanceResource<PostResource>,
     ListEnabled<Post>,
     CreateEnabled<CreatePostRequest, CreatePostResponse> {
	
    withId = (id: any):PostResource =>{
		return new PostResource(id,this.getPath(),this.getClient());
	};
    
    
    list = () : Promise<ListResponse<Post>> =>{
        return ResourceUtils.CallListWithSuffix(this,null,null,null);
    }
    
    create = (payload: CreatePostRequest): Promise<CreatePostResponse> => {
        return ResourceUtils.CallCreate(this, payload).then((response: CreatePostResponse) => {
              SigningUtils.createSigningObject(response, this.getClient(), `${this.getClient().getPath()}/posts`);
              return response;
        });
    }    
    
}


export class PostResource extends InstanceResource
 implements 
    GetEnabled<Post> {
    
    get = ():Promise<Post> =>{
        return ResourceUtils.CallGet(this,null);
    }
    
    
    delete = () : Promise<EmptyResponse> => {
        return <any>ResourceUtils.CallDelete(this,null);
    }
    
    
}

export interface CreatePostRequest {
    userId: number;
    id: number;
    title: string;
    body: string;
}

export interface CreatePostResponse extends CreatePostRequest, Signable {}